@@ -54,3 +54,15 @@ class Enumeration(Enum):
 
     def __repr__(self):
         return str(self)
+
+    def __eq__(self, other: 'Enumeration') -> bool:
+        return (
+            self.__class__.__qualname__ == other.__class__.__qualname__ and
+            (other.name == self.name and self.value == other.value)
+        )
+
+    def __hash__(self) -> int:
+        hash_code = 7
+        hash_code = 31 * hash_code + (0 if self.name is None else hash(self.name))
+        hash_code = 31 * hash_code + (0 if self.value is None else hash(self.value))
+        return hash_code
